Learn R Programming

Rnightlights (version 0.1.2)

createNlDataDirs: Create required data subdirectories in the root data path

Description

Create required data subdirectories in the root data path

Usage

createNlDataDirs()

Arguments

Value

None

Examples

Run this code
# NOT RUN {
  
# }
# NOT RUN {
createNlDataDirs()
# }
# NOT RUN {
    
# }

Run the code above in your browser using DataLab