Learn R Programming

Rnightlights (version 0.1.2)

getCtryShpLowestLyrName: Get the name of the lowest ctry admin level

Description

Get the name of the lowest ctry admin level

Usage

getCtryShpLowestLyrName(ctryCode)

Arguments

ctryCode

the ctryCode of interest

Value

character string The name of the lowest admin level