getCtryShpLowestLyrNames: Get the name of the lowest ctry admin level
Description
Get the name of the lowest ctry admin level
Usage
getCtryShpLowestLyrNames(ctryCodes = NULL,
gadmVersion = pkgOptions("gadmVersion"), custPolyPath = NULL)Arguments
ctryCodes
character ctryCodes the ctryCodes of interest
custPolyPath
Alternative to GADM. A path to a custom shapefile zip
Value
character string The name of the lowest admin level