Learn R Programming

Rnightlights (version 0.1.2)

getNlTiles: Create mapping of nightlight tiles

Description

Creates a data.frame mapping nightlight tile names to their vertice coordinates. This is used to identify nightlight tiles as well as to build a spatial polygons dataframe used to plot the tiles. OLS only has one tile for the whole world and thus has a dummy entry. OLS is included to prevent code duplication by writing separate functions for OLS.

Usage

getNlTiles(nlType)

Arguments

nlType

the nlType of interest

Value

A data.frame of names of tiles and lon-lat coordinate of top-left corner of each

Examples

Run this code
# NOT RUN {
getNlTiles("VIIRS")
# }
# NOT RUN {
# }
# NOT RUN {
getNlTiles("OLS")
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab