Learn R Programming

Rnightlights (version 0.1.2)

getNlUrlVIIRS: Function to return the url of the VIIRS tile to download

Description

Function to return the url of the VIIRS tile to download given the year, month, and nlTile index

Usage

getNlUrlVIIRS(nlYearMonth, tileNum)

Arguments

nlYearMonth

character string yearmonth in "YYYYMM' format e.g. "201204"

tileNum

The integer index of the tile to download as given by getNlTiles("VIIRS")

Value

Character string Url of the VIIRS tile file

Examples

Run this code
# NOT RUN {
tileUrl <- getNlUrlVIIRS("201204", "1")
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab