Learn R Programming

Rnightlights (version 0.1.2)

listNlTiles: List locally cached tiles

Description

List the tiles which have been downloaded previously and are currently cached in the local tiles folder

Usage

listNlTiles(nlTypes = NULL, nlPeriods = NULL, source = "local")

Arguments

nlTypes

A character vector of nlTypes to filter by

nlPeriods

A character vector of nlPeriods to filter by

source

Character string. Whether to check data availability. "local" or "remote". Default is "local".

Value

a list of locally cached nlTiles or NULL

Examples

Run this code
# NOT RUN {
#list all tiles
listNlTiles()

#list all VIIRS tiles
listNlTiles(nlTypes = "VIIRS")

#list all VIIRS tiles available in the years 2012-2014. Note VIIRS data
#starts in 201204
listNlTiles(nlTypes = "VIIRS", nlPeriods = nlRange("201204", "201412"))

#filter data
listNlTiles(nlTypes = "OLS", nlPeriods = c("2012", "2013"))

# }

Run the code above in your browser using DataLab