getCtryShpLyrName: Get the standard name of a polygon layer for a country
Description
Get the standard name of a polygon layer for a country. Used to refer to a polygon layer by name.
i.e. for CTRYCODE & lyrNum="0": lyrName="CTRYCODE_adm0", lyrNum="1": lyrName="KEN_adm1". Note this #' is different from the country official administration level name.
Usage
getCtryShpLyrName(ctryCode, lyrNum)
Arguments
ctryCode
the ISO3 code for the country
lyrNum
the order of the layer starting from 0 = country level, 1 = first admin level