powered by
Function to return the url of the VIIRS tile to download given the year, month, and nlTile index
getNlUrlVIIRS(nlYearMonth, tileNum)
character string yearmonth in "YYYYMM' format e.g. "201204"
The integer index of the tile to download as given by getNlTiles("VIIRS")
Character string Url of the VIIRS tile file
# NOT RUN { tileUrl <- getNlUrlVIIRS("201204", "1") # } # NOT RUN { # }
Run the code above in your browser using DataLab